********************************************************************************
****************************Main Dataanalysis ********************************** 
********************************************************************************

clear all
clear matrix

* Set everything to max
set matsize 11000
set maxvar 120000

set more off, perm
capture log close
log using "C:/Userdata/Shared/Logs/School, political participation/dataanalysis.text", replace text 
do "C:/Userdata/Shared/Dofiles/DoData/School, political participation/programs.do"		
cd "D:/Data/ProjData/School, political participation/mod/"
global outputfolder "C:/Userdata/Shared/Output/School, political participation"
graph set window fontface "Arial"
use "Finaldataset.dta", clear


********************************************************************************
* This dofiles concists of the following parts:
* (1): Data analysis for the main paper. 
* (2): Additional robustness checks where some is presented in the online appendix. 
* (3): Mechanism analysis where some is presented in the online appendix.  
********************************************************************************


********************************************************************************
// Some additional variable definition for the dataanalysis
********************************************************************************

destring kommun2009, replace													/* Same municipality fixed effect for all specifications */
rename *evernotnompe* *evnotnompe*

** Rescale independent variable and lag/lead to politicians per class (assuming 50 parents per class) **
foreach i in "" "_lag1" "_lead1" {
	local j = subinstr(subinstr("`i'","_"," (",.),"1",")",.)
	di "`j'"
	
	* Main treatment
	gen politicians_pq`i' = share_nompe`i' * 50	// pq = per quinquaginta
	label var politicians_pq`i' "Number of politicians`j'" 
	
	* Alternative treatment: elected politicians
	gen elected_politicians_pq`i' = share_inoffice`i' * 50	// pq = per quinquaginta
	label var elected_politicians_pq`i' "Number of politicians`j'"
	
	* Nominated but not during highschool
	gen evnotnompe_politicians_pq`i' = share_evnotnompe`i' * 50	// pq = per quinquaginta
	label var evnotnompe_politicians_pq`i' "Number of politicians`j'"	
}


gen count_nompe = round(share_nompe * (count-1) * 2,.01)
tab count_nompe
gen binary_nompe = cond(count_nompe>0,1,0,.) if !missing(count_nompe)
gen ln_nompe = ln(count_nompe+1)
gquantiles quant_nompe = share_nompe if avgar >= 1996 & parent_nompe != 1 & avgar <= 2010, xtile nquantiles(5) // Note that they are of uneven size because of many zeroes
label var binary_nompe "At least one politician"
label var ln_nompe "Log. number of politicians"
label define quantiles 1 "First quintile" 2 "Second quintile" 3 "Third quintile" 4 "Fourth quintile" 5 "Fifth quintile"
label value quant_nompe quantiles


********************************************************************************
// Macros for variable lists and output formatting
********************************************************************************

* Covariates macros
global CovInd "i_sex i_immig"
global CovParent "f_socialbidragfamilj f_sysselsatt f_yearseducation f_zink m_socialbidragfamilj m_sysselsatt m_yearseducation m_zink"
global CovParentClass "share_f_socialbidragfamilj share_f_sysselsatt share_f_yearseducation share_f_zink share_m_socialbidragfamilj share_m_sysselsatt share_m_yearseducation share_m_zink"
global indvar "politicians_pq"
global lag "politicians_pq_lag1 politicians_pq_lead1"

* Sample macros
global includeEP avgar >= 1996 & parent_nompe != 1 & avgar < 2009
global includeother avgar >= 1996 & parent_nompe != 1 & avgar <= 2010

* Estout options
#delimit ;
global statatab
	label ar2 se nogaps b(3)  
	nostar
	drop(*.avgar *.ko*);
global latextab 
	replace label se nogaps b(3) 
	compress booktabs nonotes 
	nostar
	alignment(D{.}{.}{2.3})
	varlabels(_cons "Constant")
	keep(politicians_pq);
global latextab2
	replace label se nogaps b(3)  
	compress booktabs nonotes 
	nostar
	alignment(D{.}{.}{2.3})
	varlabels(_cons "Constant")
	keep(npa c.npa#c.politicians_pq politicians_pq) noomitted;
global latextab3 
	replace label se nogaps b(3) 
	compress booktabs nonotes 
	nostar
	alignment(D{.}{.}{2.3})
	varlabels(_cons "Constant")
	keep(politicians_pq);
global latextab4 
	replace label se nogaps b(3) 
	compress booktabs nonotes 
	nostar
	alignment(D{.}{.}{2.3})
	varlabels(_cons "Constant")
	keep(politicians_pq samesams inter);
global latextab5 
	replace label se nogaps b(3) 
	compress booktabs nonotes 
	nostar
	alignment(D{.}{.}{2.3})
	varlabels(_cons "Constant")
	keep(politicians_pq_*);	
global latextab_revision 
	replace label se nogaps b(3) 
	compress booktabs nonotes 
	nostar
	alignment(D{.}{.}{2.3})
	varlabels(_cons "Constant")
	keep(binary_nompe ln_nompe 2.quant_nompe 3.quant_nompe 4.quant_nompe 5.quant_nompe);
global stats1
	stats(ymean icovs pcovs cohort muni ar2 N,
		fmt(3 0 0 0 0 3 %11.0fc)
		layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "@" "\multicolumn{1}{c}{@}")
		label("Mean dep.var." "Individual covariates" "Parent covariates" "Cohort FE" "Muni. FE" "Adjusted R2" "Observations")
	);
global stats2
	stats(ymean icovs pcovs cohort muni schoolprogramtrend r2_a N,
		fmt(3 0 0 0 0 0 3 %11.0fc)
		layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "@" "\multicolumn{1}{c}{@}")
		label("Mean dep.var." "Individual covariates" "Parent covariates" "Cohort FE" "Muni. FE" "School-program trend" "Adjusted R2" "Observations")
	);
global stats3
	stats(ymean icovs pcovs cohort muni schooltrend programtrend schoolprogramtrend lag r2_a N,
		fmt(3 0 0 0 0 0 0 0 0 3 %11.0fc)
		layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "@" "\multicolumn{1}{c}{@}")
		label("Mean dep.var." "Individual covariates" "Parent covariates" "Cohort FE" "Muni. FE" "School trend" "Program trend" "School-program trend" "Lagged and lead share" "Adjusted R2" "Observations")
	);
global stats4
	stats(ymean icovs pcovs ccovs cohort muni ar2 N,
		fmt(3 0 0 0 0 0 3 %11.0fc)
		layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}" "@" "\multicolumn{1}{c}{@}")
		label("Mean dep.var." "Individual covariates" "Parent covariates i" "Parent Class covariates" "Cohort FE" "Muni. FE" "Adjusted R2" "Observations")
	);
#delimit cr


********************************************************************************
// Main results
********************************************************************************

eststo clear
foreach depvar in turnout_e turnout_r {
	if "`depvar'" == "turnout_e" local include $includeEP
	if "`depvar'" == "turnout_r" local include $includeother
	eststo: areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/main_turnout.tex", $latextab $stats1 mtitles("Vote09" "Vote09" "Vote09" "Vote10" "Vote10" "Vote10")
eststo clear

foreach depvar in i_evernominated i_everelected {
	if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother
	eststo: areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/main_nomelec.tex", $latextab $stats1 mtitles("Nom" "Nom" "Nom" "Elec" "Elec" "Elec")
eststo clear




********************************************************************************
// Additional output
********************************************************************************

** Main text: Placebo outcomes **
rename Gkap cog
rename Psyf noncog
rename GBP gpa
rename GPA_9 gpa9
destring cog noncog gpa gpa9, replace

* Standardize the variable using graduating year from upper secondary school
foreach k in cog noncog {														
	egen mean_`k' = mean(`k'), by(avgar)
	egen sd_`k' = sd(`k'), by(avgar)
	gen z`k' = (`k' - mean_`k') / sd_`k'
}

* Standardize the variable using graduating year and the type of grading system as group variables */
foreach k in gpa gpa9 {														
	egen mean_`k' = mean(`k'), by(avgar betygsystem)							
	egen sd_`k' = sd(`k'), by(avgar betygsystem)
	gen z`k' = (`k' - mean_`k') / sd_`k'
}

* Create variables 
egen parent_turnout = rowmean(turnout_f_e turnout_m_e turnout_f_r turnout_m_r)
replace parent_turnout = parent_turnout * 100
egen parent_evernombefore = rowmean(father_evernominatedbefore mother_evernominatedbefore)
replace parent_evernombefore = parent_evernombefore * 100

gen turnout_p_e = turnout_f_e + turnout_m_e
gen turnout_p_r = turnout_f_r + turnout_m_r
gen parent_evernominatedbefore = father_evernominatedbefore + mother_evernominatedbefore
gen parent_everelectedbefore = father_everelectedbefore + mother_everelectedbefore

* Create regression table for placebo outcomes
foreach depvar in zgpa9 cog noncog gpa parent_turnout parent_evernombefore {
	eststo:  areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if $includeother, absorb(schoolprogram) cluster(schoolprogram)
	estadd local icovs "Yes"
	estadd local pcovs "Yes"
	estadd local cohort "Yes"
	estadd local muni "Yes"
	estadd ysumm
}
esttab, keep(politicians_pq) se nostar mtitles("GradesC" "Cog.Abi." "NCog.Abi" "GradesU" "P.Turnout" "P.Nomin.") 
esttab using "$outputfolder/tex/placebo.tex", $latextab $stats1 mtitles("GradesC" "Cog.Abi." "NCog.Abi" "GradesU" "P.Turnout" "P.Nomin.")
eststo clear





**Main text: Adjust for school and program trends**

* Generate grouping variables
gen school = real(substr(schoolprogram,1,strpos(schoolprogram,"_")-1))
gen schoolyear = string(school) + "_" + string(avgar)
encode program_highschool, gen(prog_enc)
capture encode schoolprogram, gen(schoolprogram_enc)
encode schoolyear, gen(schoolyear_enc)

* Robustness table to use in the robustness section of the main paper
foreach depvar in turnout_e turnout_r i_evernominated i_everelected {
	if "`depvar'" == "turnout_e" local include $includeEP
	else local include $includeother
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram_enc avgar kommun2009 i.schoolprogram_enc##c.avgar) cluster(schoolprogram_enc)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schoolprogramtrend "Yes"
}
esttab, keep($indvar) nostar
esttab using "$outputfolder/tex/schoolprogramtrends.tex", $latextab3 $stats2 mtitles("Vote09" "Vote10" "Nom" "Elec") 
eststo clear




** Main text: Mechanism analysis. ** 

gen politicians_pq_nov = share_vt09no * 50
gen politicians_pq_vot = politicians_pq - politicians_pq_nov
label var politicians_pq_nov "Number of politicians n.v stud." 
label var politicians_pq_vot "Number of politicians vot. stud."
label var politicians_pq "Number of politicians (during)"
label var evnotnompe_politicians_pq "Number of politicians not during" 

eststo clear
foreach j in "politicians_pq_vot politicians_pq_nov" "politicians_pq evnotnompe_politicians_pq" { 
	foreach depvar in turnout_e turnout_r i_evernominated i_everelected {
		if "`depvar'" == "turnout_e" local include $includeEP
		if "`depvar'" == "turnout_r" local include $includeother
		if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother
		eststo: areg `depvar' `j' i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
			estadd local icovs "Yes"
			estadd local pcovs "Yes"
			estadd local cohort "Yes"
			estadd local muni "Yes"
			estadd ysumm
}
}
esttab using "$outputfolder/tex/mechnism_shorttable_main.tex", replace label se nogaps b(3) nostar compress booktabs nonotes alignment(D{.}{.}{2.3}) varlabels(_cons "Constant") keep(politicians_pq politicians_pq_nov politicians_pq_vot evnotnompe_politicians_pq) $stats1 mtitles("Vote09" "Vote10" "Nom" "Elec" "Vote09" "Vote10" "Nom" "Elec")

eststo clear
global indvar "politicians_pq"
label var politicians_pq "Number of politicians"




** Main text: Nascent political ambition **

* Spline version + histogram
foreach depvar in turnout_e turnout_r i_evernominated i_everelected {
	gen npa = hat2_`depvar'
	if "`depvar'" == "turnout_e" local include $includeEP
	else local include $includeother 

	* Create splines and save them in a macro
	mkspline2 spline_ = npa if `include', cubic
	ds spline_*
	local ia = subinstr("`r(varlist)'","spline_","c.politicians_pq#c.spline_",.)
	global indvar = "spline_* " + "politicians_pq " + "`ia'"

	* Identify percentiles
	areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
	gen sample_`depvar' = 1 if e(sample)
	egen nparank = rank(npa) if e(sample), unique
	egen npamaxrank = max(nparank)

	* Variables where coefficients are saved
	gen pctile = _n * 5 if _n < 20
	gen me = .
	gen ul = .
	gen dl = .
	
	* Estimate marginal effects 
	forvalues p = 5(5)95 {

		* Set all splines to zero at percentile p
		forvalues s = 1/4 {
			su spline_`s' if nparank == round(npamaxrank/100*`p',1)
			local s`s' = r(mean)
			replace spline_`s' = spline_`s' - `s`s''
		}
		
		* Regress and save marginal effect + confidence interval
		areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		replace me = _b[politicians_pq] if pctile == `p'
		replace ul = me + 1.96 * _se[politicians_pq] if pctile == `p'
		replace dl = me - 1.96 * _se[politicians_pq] if pctile == `p'
		
		* Reset splines
		forvalues s = 1/4 {
			replace spline_`s' = spline_`s' + `s`s''
		}
		
	}
	
	* Graph the marginal effects
	line me ul dl pctile,	///
		scheme(s1mono) 		///
		lpattern(solid dash dash) lcolor(black black black) ///
		legend(off) ///
		xtitle("Percentile of NPA") ytitle("Marginal effect")	///
		yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
		yline(0,lwidth(thin))
	graph export "$outputfolder/img/npa_splines_me_`depvar'.pdf", as(pdf) replace
	graph export "$outputfolder/img/npa_splines_me_`depvar'.eps", as(eps) replace

	* Histogram over NPA
	hist npa if sample_`depvar', ///
	percent ytitle("Percent") xtitle("Probability of participation, per cent")	///
	scheme(s1mono) fcolor(gs10) lwidth(thin) ///
 	yscale(titlegap(1.5)) ///
	xscale(titlegap(1.5))
	graph export "$outputfolder/img/hist_npa_`depvar'.pdf", as(pdf) replace
	graph export "$outputfolder/img/hist_npa_`depvar'.eps", as(eps) replace
	
	drop pctile me ul dl
	drop nparank npamaxrank
	drop spline_*
	drop sample_`depvar'
	drop npa
}
global indvar "politicians_pq"



** Appendix (col 3/6) with transformations of the treatment variable **


foreach depvar in turnout_e turnout_r {
	if "`depvar'" == "turnout_e" local include $includeEP
	if "`depvar'" == "turnout_r" local include $includeother
	eststo: areg `depvar' binary_nompe i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
	eststo: areg `depvar' i.quant_nompe i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
	eststo: areg `depvar' ln_nompe i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		
} 
esttab using "$outputfolder/tex/nonlinear_turnout.tex", $latextab_revision $stats1 mtitles("Vote09" "Vote09" "Vote09" "Vote10" "Vote10" "Vote10") noomitted
eststo clear

foreach depvar in i_evernominated i_everelected {
	if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother
	eststo: areg `depvar' binary_nompe i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
	eststo: areg `depvar' i.quant_nompe i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
	eststo: areg `depvar' ln_nompe i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/nonlinear_nomelec.tex", $latextab_revision $stats1 mtitles("Nom" "Nom" "Nom" "Elec" "Elec" "Elec") noomitted
eststo clear



** Appendix: Elected as variable of interest **
rename politicians_pq politicians_pq_BK
rename elected_politicians_pq politicians_pq

foreach depvar in turnout_e turnout_r {
	if "`depvar'" == "turnout_e" local include $includeEP
	if "`depvar'" == "turnout_r" local include $includeother
	eststo:  areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/alttreat_elected_turnout.tex", $latextab $stats1 mtitles("Vote09" "Vote09" "Vote09" "Vote10" "Vote10" "Vote10")
eststo clear

foreach depvar in i_evernominated i_everelected {
	if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother
	eststo:  areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/alttreat_elected_nomelec.tex", $latextab $stats1 mtitles("Nom" "Nom" "Nom" "Elec" "Elec" "Elec")
eststo clear

rename politicians_pq elected_politicians_pq
rename politicians_pq_BK politicians_pq 





** Appendix: Trends, additional specifications with lags and leads **
global indvar "politicians_pq"
foreach depvar in turnout_e turnout_r {
	if "`depvar'" == "turnout_e" local include $includeEP
	else local include $includeother
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram_enc avgar kommun2009 i.school##c.avgar i.prog_enc##c.avgar) cluster(schoolprogram_enc)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schooltrend "Yes"
		estadd local programtrend "Yes"
		estadd local schoolprogramtrend "No"
		estadd local schoolyearfixed "No"
		estadd local lag "No"
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram_enc avgar kommun2009 i.schoolprogram_enc##c.avgar) cluster(schoolprogram_enc)	
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schooltrend "No"
		estadd local programtrend "No"
		estadd local schoolprogramtrend "Yes"
		estadd local schoolyearfixed "No"
		estadd local lag "No"
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass politicians_pq_lag1 politicians_pq_lead1 if `include', absorb(schoolprogram_enc avgar kommun2009 i.schoolprogram_enc##c.avgar) cluster(schoolprogram_enc)	
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schooltrend "No"
		estadd local programtrend "No"
		estadd local schoolprogramtrend "Yes"
		estadd local schoolyearfixed "No"
		estadd local lag "Yes"
}
esttab, keep($indvar) nostar
esttab using "$outputfolder/tex/appendix_trends_turnout.tex", $latextab3 $stats3 mtitles("Vote09" "Vote09" "Vote09" "Vote10" "Vote10" "Vote10")
eststo clear
	
foreach depvar in i_evernominated i_everelected {
	if "`depvar'" == "turnout_e" local include $includeEP
	else local include $includeother
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram_enc avgar kommun2009 i.school##c.avgar i.prog_enc##c.avgar) cluster(schoolprogram_enc)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schooltrend "Yes"
		estadd local programtrend "Yes"
		estadd local schoolprogramtrend "No"
		estadd local schoolyearfixed "No"
		estadd local lag "No"
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram_enc avgar kommun2009 i.schoolprogram_enc##c.avgar) cluster(schoolprogram_enc)	
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schooltrend "No"
		estadd local programtrend "No"
		estadd local schoolprogramtrend "Yes"
		estadd local schoolyearfixed "No"
		estadd local lag "No"
	eststo:  reghdfe `depvar' $indvar $CovInd $CovParent $CovParentClass politicians_pq_lag1 politicians_pq_lead1 if `include', absorb(schoolprogram_enc avgar kommun2009 i.schoolprogram_enc##c.avgar) cluster(schoolprogram_enc)	
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
		estadd local schooltrend "No"
		estadd local programtrend "No"
		estadd local schoolprogramtrend "Yes"
		estadd local schoolyearfixed "No"
		estadd local lag "Yes"
}
esttab, keep($indvar) nostar
esttab using "$outputfolder/tex/appendix_trends_nomelec.tex", $latextab3 $stats3 mtitles("Nom" "Nom" "Nom" "Elec" "Elec" "Elec")
eststo clear



** Appendix: Set sample restriction to 20-35 students per class **
bys class: egen csize = count(LopNr)
foreach depvar in turnout_e turnout_r {
	if "`depvar'" == "turnout_e" local include $includeEP & inrange(csize,20,35)
	if "`depvar'" == "turnout_r" local include $includeother & inrange(csize,20,35)
	eststo:  areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/2035students_turnout.tex", $latextab $stats1 mtitles("Vote09" "Vote09" "Vote09" "Vote10" "Vote10" "Vote10")
eststo clear

foreach depvar in i_evernominated i_everelected {
	if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother & inrange(csize,20,35)
	eststo:  areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo:  areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/2035students_nomelec.tex", $latextab $stats1 mtitles("Nom" "Nom" "Nom" "Elec" "Elec" "Elec")
eststo clear

drop csize



** Appendix: Loop over sample restrictions to create line graph **
* Class size restriction
bys class: egen csize = count(LopNr)
gen maxsize = .
foreach depvar in turnout_e turnout_r i_evernominated i_everelected {
	
	gen gwcsr_b_`depvar' = .
	gen gwcsr_u_`depvar' = .
	gen gwcsr_l_`depvar' = .
	gen gwcsr_n_`depvar' = .

	local j 0
	forvalues i = 25(5)300 {
		local j = `j' + 1

		* Update sample restrictions
		if "`depvar'" == "turnout_e" local include $includeEP & csize <= `i'
		else local include $includeother & csize <= `i'

		* Conduct the regression (a copy of column 3) and store coefficients as variables
		 areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		replace maxsize = `i' if _n == `j'
		replace gwcsr_b_`depvar' = _b[politicians_pq] if _n == `j'
		replace gwcsr_l_`depvar' = _b[politicians_pq] - 1.96 * _se[politicians_pq] if _n == `j'
		replace gwcsr_u_`depvar' = _b[politicians_pq] + 1.96 * _se[politicians_pq] if _n == `j'
		replace gwcsr_n_`depvar' = e(N) if _n == `j'
	}
	
	* Create the graph
	line gwcsr_b_`depvar' gwcsr_u_`depvar' gwcsr_l_`depvar' maxsize,	///
		scheme(s1mono) ///
		lpattern(solid dash dash) lcolor(black black black) ///
		legend(off) ///
		xtitle("Maximum class size") ytitle("Estimated effect")	///
		yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
		yline(0,lwidth(thin))
	graph export "$outputfolder/img/maxsize_`depvar'.pdf", as(pdf) replace
	graph export "$outputfolder/img/maxsize_`depvar'.eps", as(eps) replace
	drop gwcsr*
	
}

* Treatment restriction (number of politicians)
gen maxtreat = .
foreach depvar in turnout_e turnout_r i_evernominated i_everelected {
	gen gwcsr_b_`depvar' = .
	gen gwcsr_u_`depvar' = .
	gen gwcsr_l_`depvar' = .
	gen gwcsr_n_`depvar' = .

	forvalues i = 1(1)20 {

		* Update sample restrictions
		if "`depvar'" == "turnout_e" local include $includeEP & politicians_pq <= `i'
		else local include $includeother & politicians_pq <= `i'

		* Conduct the regression (a copy of column 3) and store coefficients as variables
		 areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		replace maxtreat = `i' if _n == `i'
		replace gwcsr_b_`depvar' = _b[politicians_pq] if _n == `i'
		replace gwcsr_l_`depvar' = _b[politicians_pq] - 1.96 * _se[politicians_pq] if _n == `i'
		replace gwcsr_u_`depvar' = _b[politicians_pq] + 1.96 * _se[politicians_pq] if _n == `i'
		replace gwcsr_n_`depvar' = e(N) if _n == `i'
	}
	
	* Create the graph
	line gwcsr_b_`depvar' gwcsr_u_`depvar' gwcsr_l_`depvar' maxtreat,	///
		scheme(s1mono) ///
		lpattern(solid dash dash) lcolor(black black black) ///
		legend(off) ///
		xtitle("Maximum treatment") ytitle("Estimated effect")	///
		yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
		yline(0,lwidth(thin))
	graph export "$outputfolder/img/maxtreat_`depvar'.pdf", as(pdf) replace
	graph export "$outputfolder/img/maxtreat_`depvar'.eps", as(eps) replace
	drop gwcsr*
}
drop maxtreat



** Appendix: Linear version Nascent political ambition**
gen npa = .
foreach depvar in turnout_e turnout_r i_evernominated i_everelected {

	replace npa = hat2_`depvar'
	global indvar c.npa##c.politicians_pq
	if "`depvar'" == "turnout_e" local include $includeEP
	else local include $includeother 
	
	* A copy of column 3 + interaction with NPA
	eststo:  areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
	
	gen sample_`depvar' = e(sample)
	su politicians_pq if e(sample)
	gen meantreat_`depvar' = r(mean)
	
	estadd local icovs "Yes"
	estadd local pcovs "Yes"
	estadd local cohort "Yes"
	estadd local muni "Yes"
	estadd local Lag "No"
	estadd ysumm
	
	* Marginal effects at different percentiles of the distribution
	gen me = .
	gen se = .
	gen decile = _n if _n < 10
	centile npa if e(sample), centile(10 20 30 40 50 60 70 80 90)
	margins, dydx(politicians_pq) at(npa=`r(c_1)' npa=`r(c_2)' npa=`r(c_3)' npa=`r(c_4)' npa=`r(c_5)' npa=`r(c_6)' npa=`r(c_7)' npa=`r(c_8)' npa=`r(c_9)')
	matrix b = r(b)
	matrix V = r(V)
	forvalues i = 1/9 {
		replace me = b[1,`i'] if decile == `i'
		replace se = sqrt(V[`i',`i']) if decile == `i'
	}
	gen ul = me + 1.96 * se
	gen dl = me - 1.96 * se
	
	* Graph the marginal effects
	line me ul dl decile,	///
		scheme(s1mono) 		///
		lpattern(solid dash dash) lcolor(black black black) ///
		legend(off) ///
		xtitle("Decile of NPA") ytitle("Marginal effect")	///
		yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
		yline(0,lwidth(thin))
	graph export "$outputfolder/img/npa_me_`depvar'.pdf", as(pdf) replace
	graph export "$outputfolder/img/npa_me_`depvar'.eps", as(eps) replace
	drop decile me se ul dl

}
esttab, order(c.npa#c.politicians_pq npa) keep(npa c.npa#c.politicians_pq politicians_pq _cons) noomitted mtitles("Voted09" "Voted10" "Nominated" "Elected") 
eststo clear
global indvar politicians_pq
drop npa


** Appendix: Main analysis tables, but with 5 columns (additional specifications)**
foreach depvar in turnout_e turnout_r {
	eststo clear
	if "`depvar'" == "turnout_e" local include $includeEP
	if "`depvar'" == "turnout_r" local include $includeother
	eststo: areg `depvar' $indvar i.avgar if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "No"
		estadd local pcovs "No"
		estadd local ccovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local ccovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd $CovParent if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local ccovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local ccovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local ccovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
esttab using "$outputfolder/tex/Appendix_5col_`depvar'.tex", $latextab $stats4 nomtitles
eststo clear
} 



foreach depvar in i_evernominated i_everelected {
	eststo clear
	if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother
	eststo: areg `depvar' $indvar i.avgar if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "No"
		estadd local pcovs "No"
		estadd local ccovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local ccovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd $CovParent if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local ccovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local ccovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local ccovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm

esttab using "$outputfolder/tex/Appendix_5col_`depvar'.tex", $latextab $stats4 nomtitles
eststo clear
} 



** Appendix:  Mechanism analysis. Are the parents affected by other politician parents/ children of politician parents? 

eststo clear
eststo: areg father_evernominatedafter politicians_pq i.avgar i.kommun2009 $CovParent $CovParentClass if $includeother, absorb(schoolprogram) cluster(schoolprogram)
estadd local icovs "No"
estadd local pcovs "Yes"
estadd local cohort "Yes"
estadd local muni "Yes"
estadd ysumm
eststo: areg mother_evernominatedafter politicians_pq i.avgar i.kommun2009 $CovParent $CovParentClass if $includeother, absorb(schoolprogram) cluster(schoolprogram)
estadd local icovs "No"
estadd local pcovs "Yes"
estadd local cohort "Yes"
estadd local muni "Yes"
estadd ysumm
eststo: areg father_evernominatedafter politicians_pq_vot politicians_pq_nov i.avgar i.kommun2009 $CovParent $CovParentClass if $includeother, absorb(schoolprogram) cluster(schoolprogram)
estadd local icovs "No"
estadd local pcovs "Yes"
estadd local cohort "Yes"
estadd local muni "Yes"
estadd ysumm
eststo: areg mother_evernominatedafter politicians_pq_vot politicians_pq_nov i.avgar i.kommun2009 $CovParent $CovParentClass if $includeother, absorb(schoolprogram) cluster(schoolprogram)
estadd local icovs "No"
estadd local pcovs "Yes"
estadd local cohort "Yes"
estadd local muni "Yes"
estadd ysumm
esttab using "$outputfolder/tex/mechnism_parents.tex", replace label se nogaps b(3) nostar compress booktabs nonotes alignment(D{.}{.}{2.3}) varlabels(_cons "Constant") keep(politicians_pq politicians_pq_nov politicians_pq_vot) $stats1 mtitles("Father.Nom" "Mother.Nom" "Father.Nom" "Mother.Nom")
eststo clear



** Appendix: Running for the same political party
local include $includeother
foreach p in M KD L C S MP V SD {
	gen sameparty = i_`p'
	gen same_pq = share_nompe_`p' * 50
	gen others_pq = politicians_pq - same_pq

	global indvar "same_pq others_pq"
	label var same_pq "Numer of politicians SP"
	label var others_pq "Number of politcians other"
	 
	eststo: areg sameparty $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg sameparty $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg sameparty $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm

	local p = lower("`p'")
	esttab using "$outputfolder/tex/mechnism_partisan_`p'.tex", replace label se nogaps b(3) compress nostar booktabs nonotes alignment(D{.}{.}{2.3}) varlabels(_cons "Constant") keep($indvar) $stats1 mtitles("Nom" "Nom" "Nom")
	drop sameparty 
	drop same_pq 
	drop others_pq 
	eststo clear	
}


** Appendix: Political interest **
local include $includeother
global indvar "politicians_pq"
	eststo: areg discpol $indvar i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg discpol $indvar i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg discpol $indvar i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
esttab using "$outputfolder/tex/mechnism_poldisc.tex", replace label se nogaps b(3) compress booktabs nonotes nostar alignment(D{.}{.}{2.3}) varlabels(_cons "Constant") keep($indvar) $stats1 mtitles("PolDisc" "PolDisc" "PolDisc")
eststo clear



** Interacted treatment effects with years since graduation **
gen dist09 = 2009 - avgar
gen dist10 = 2010 - avgar

replace dist09 = . if avgar > 2009
replace dist10 = . if avgar > 2010

replace dist09 = dist09/12														/*The oldest cohort defined as 1*/
replace dist10 = dist10/13

gen inter09 = dist09 * politicians_pq
gen inter10 = dist10 * politicians_pq 											/*We only include the interaction variable since we already control for cohort fixed effects.*/

label var dist09 "Years grad 2009"
label var dist10 "Years grad 2010"
label var inter09 "Years grad 2009 * N. Pol."
label var inter10 "Years grad 2010 * N. Pol."

eststo clear
foreach depvar in turnout_e turnout_r {
	if "`depvar'" == "turnout_e" local include $includeEP
	if "`depvar'" == "turnout_e" global age "inter09"
	if "`depvar'" == "turnout_r" local include $includeother
	if "`depvar'" == "turnout_r" global age "inter10"
	eststo: areg `depvar' $indvar $age i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar $age i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar $age i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/turnout_ageinter.tex", $stats1 replace label se nogaps b(3) compress booktabs nonotes nostar alignment(D{.}{.}{2.3}) varlabels(_cons "Constant") keep(politicians_pq inter09 inter10) mtitles("Vote09" "Vote09" "Vote09" "Vote10" "Vote10" "Vote10")
eststo clear

global age "inter10"
foreach depvar in i_evernominated i_everelected {
	if "`depvar'" == "i_evernominated" | "`depvar'" == "i_everelected" local include $includeother
	eststo: areg `depvar' $indvar $age i.avgar $CovInd if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "No"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar $age i.avgar $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "No"
		estadd ysumm
	eststo: areg `depvar' $indvar $age i.avgar i.kommun2009 $CovInd $CovParent $CovParentClass if `include', absorb(schoolprogram) cluster(schoolprogram)
		estadd local icovs "Yes"
		estadd local pcovs "Yes"
		estadd local cohort "Yes"
		estadd local muni "Yes"
		estadd ysumm
} 
esttab using "$outputfolder/tex/nomelec_ageinter.tex", $stats1 replace label se nogaps b(3) compress booktabs nonotes nostar alignment(D{.}{.}{2.3}) varlabels(_cons "Constant") keep(politicians_pq $age) mtitles("Nom" "Nom" "Nom" "Elec" "Elec" "Elec")
eststo clear









******
clear all
log close


